Decoder

Struct Decoder 

pub struct Decoder { /* private fields */ }
Opus decoder.

Implementations

Source

impl Decoder

pub fn new(freq: SamplingRate, channels: Channels) -> Result<Self, DecoderError>

Construct decoder from requested sampling rate and number of channels.

See also opus_decoder_get_size and opus_decoder_init.

pub fn get_nb_samples_total(&self, data: &[u8]) -> Result<usize, DecoderError>

Return the number of samples in the opus data multiplied by the number of channels.

This value can be used for output buffer size for decoding when total number of samples in frame is expected.

See also Decoder::get_nb_samples.

pub fn get_nb_samples(&self, data: &[u8]) -> Result<usize, DecoderError>

Return the number of samples in the opus data.

This value can be used for audio output when frame size is expected, i.e. the number of samples per channel.

See also opus_decoder_get_nb_samples.

pub fn decode<'output>( &mut self, data: &[u8], output: &'output mut [i16], ) -> Result<&'output [i16], DecoderError>

Decode opus packet from data into output buffer.

Returns decoded frame stored on output buffer. Its length is total number of samples in a frame.

let mut decoder = Decoder::new(SamplingRate::F24k, Channels::Mono).unwrap();
let mut output = Vec::new();
output.resize(decoder.get_nb_samples_total(data).unwrap(), 0);
let output = decoder.decode(data, &mut output).unwrap();
println!("Got {} samples of data in output", output.len());

See also opus_decode.